==> dtk6declarative-debug-6.0.23-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.rcc/qmlcache/dtk6declarative_qml/HelpAction_qml.cpp <==
// /org/deepin/dtk/HelpAction.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _org_deepin_dtk_HelpAction_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x42,0x0,0x0,0x0,0x2,0x8,0x6,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xec,0x3,0x0,0x0,0x37,0x35,0x35,0x33,
0x34,0x66,0x33,0x65,0x37,0x66,0x66,0x66,
0x32,0x34,0x65,0x64,0x37,0x63,0x63,0x62,
0x33,0x36,0x34,0x65,0x32,0x65,0x64,0x39,
0x39,0x35,0x30,0x61,0x37,0x33,0x64,0x61,
0x38,0x37,0x39,0x66,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0xe9,0x16,0x70,
0x8c,0x3b,0x5,0x92,0x7a,0xad,0x49,0xf4,
0x33,0x3b,0x6e,0x58,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x3,0x0,0x0,
0x28,0x1,0x0,0x0,0x90,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xa0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x0,0x3c,0x1,0x18,0x7,0xac,
0x2,0x7,0x0,0x0,0x18,0x6,0xd4,0x16,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd0,0x1,0x0,0x0,0xd8,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0xf8,0x1,0x0,0x0,
0x20,0x2,0x0,0x0,0x38,0x2,0x0,0x0,
0x58,0x2,0x0,0x0,0x68,0x2,0x0,0x0,
0x78,0x2,0x0,0x0,0x98,0x2,0x0,0x0,
0xd8,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x44,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x64,0x0,0x65,0x0,
0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,
0x2e,0x0,0x64,0x0,0x74,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x48,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x54,0x0,0x72,0x0,0x69,0x0,0x67,0x0,
0x67,0x0,0x65,0x0,0x72,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x54,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x67,0x0,
0x65,0x0,0x72,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x41,0x0,0x70,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x48,0x0,0x65,0x0,0x6c,0x0,
0x70,0x0,0x65,0x0,0x72,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x6c,0x0,0x65,0x0,
0x48,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0xb,0x2,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x6,0x0,0x10,0x0,0x0,0x1,0x0,0x0,
0x3c,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0x9,0x0,0x50,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x30,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x50,0x0,0xa,0x0,0xb0,0x0,
0x0,0x0,0x0,0x0
};
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4573)
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = { { 0, 0, nullptr, nullptr } };
QT_WARNING_POP
}
}

==> dtk6declarative-debug-6.0.28-1-x86_64.pkg.tar.zst: usr/src/debug/dtk6declarative/dtk6declarative/qt6/src/.rcc/qmlcache/dtk6declarative_qml/HelpAction_qml.cpp <==
// /org/deepin/dtk/HelpAction.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _org_deepin_dtk_HelpAction_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x42,0x0,0x0,0x0,0x2,0x8,0x6,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xec,0x3,0x0,0x0,0x37,0x35,0x35,0x33,
0x34,0x66,0x33,0x65,0x37,0x66,0x66,0x66,
0x32,0x34,0x65,0x64,0x37,0x63,0x63,0x62,
0x33,0x36,0x34,0x65,0x32,0x65,0x64,0x39,
0x39,0x35,0x30,0x61,0x37,0x33,0x64,0x61,
0x38,0x37,0x39,0x66,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xde,0x3,0x56,0x47,
0x94,0xe7,0x0,0xa0,0xa6,0x26,0x70,0xe4,
0xbc,0xb9,0x29,0x6a,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x3,0x0,0x0,
0x28,0x1,0x0,0x0,0x90,0x1,0x0,0x0,
0x23,0x0,0x0,0x0,0xa0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x0,0x3c,0x1,0x18,0x7,0xac,
0x2,0x7,0x0,0x0,0x18,0x6,0xd4,0x16,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd0,0x1,0x0,0x0,0xd8,0x1,0x0,0x0,
0xf0,0x1,0x0,0x0,0xf8,0x1,0x0,0x0,
0x20,0x2,0x0,0x0,0x38,0x2,0x0,0x0,
0x58,0x2,0x0,0x0,0x68,0x2,0x0,0x0,
0x78,0x2,0x0,0x0,0x98,0x2,0x0,0x0,
0xd8,0x2,0x0,0x0,0x0,0x3,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x44,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x64,0x0,0x65,0x0,
0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,
0x2e,0x0,0x64,0x0,0x74,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x41,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x48,0x0,0x65,0x0,
0x6c,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x54,0x0,0x72,0x0,0x69,0x0,0x67,0x0,
0x67,0x0,0x65,0x0,0x72,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x54,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x67,0x0,
0x65,0x0,0x72,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x41,0x0,0x70,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x48,0x0,0x65,0x0,0x6c,0x0,
0x70,0x0,0x65,0x0,0x72,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x6c,0x0,0x65,0x0,
0x48,0x0,0x65,0x0,0x6c,0x0,0x70,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x5,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x6,0x0,0x10,0x0,0x0,0x1,0x0,0x0,
0x3c,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0x9,0x0,0x50,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0xb,0x0,0x30,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x50,0x0,0xa,0x0,0xb0,0x0,
0x0,0x0,0x0,0x0
};
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4573)
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = { { 0, 0, nullptr, nullptr } };
QT_WARNING_POP
}
}
